-- CABLE TRAY DESIGN 
-- v2.4.1, July 2019
-- Marco Moraschi

-- PROBLEM DEFINITION
newdocument(0)
freq = 50
units = "meters"
type = "planar" -- definition of the problem: "planar" or "axis"
mi_probdef(freq, units, type, 1e-9)
mi_saveas("Design_NO-CableTray.fem")


-- DATA ACQUISITION

k = 1 -- counters
i = 1

mydatastring = {} -- array for parameters (string)
for i = 1, 33 do -- array initializion 
   mydatastring[i] = 0
end

mydata = {} -- array for parameters (numbers)
for i = 1, 33 do -- array initializion 
   mydata[i] = 0
end

readfrom("DATA/Input_Data.txt")

for i = 1, 32 do -- data acquisition
   local line = read("*l")
if line == nil then break end
mydatastring[k] = line
k = k+1
end

for k = 1, 32 do -- data conversion (string to number)
   mydata[k] = tonumber(mydatastring[k])
end

w1 = mydata[1]
h1 = mydata[2]
h2 = mydata[3]
gap1 = mydata[4]
gap2 = mydata[5]
d = mydata[6]
a = mydata[7]    
layer1_th = mydata[8]
layer1_mu = mydata[9]
layer1_sig = mydata[10]
layer2_th = mydata[11]
layer2_mu = mydata[12]
layer2_sig = mydata[13]
layer3_th = mydata[14]
layer3_mu = mydata[15]
layer3_sig = mydata[16]
layer4_th = mydata[17]
layer4_mu = mydata[18]
layer4_sig = mydata[19]
layer5_th = mydata[20]
layer5_mu = mydata[21]
layer5_sig = mydata[22]
layer6_th = mydata[23]
layer6_mu = mydata[24]
layer6_sig = mydata[25]
Irms1 = mydata[26]
Irms2 = mydata[27]
Irms3 = mydata[28]
phase1 = mydata[29]
phase2 = mydata[30]
phase3 = mydata[31]
bplotlength = mydata[32]

squareside=2.5*w1 -- side of the squared area 

angle1 = (phase1*2*pi)/360 -- conversion degree to rad
angle2 = (phase2*2*pi)/360
angle3 = (phase3*2*pi)/360

-- DATA CHECK

if (w1-2*(layer1_th+layer2_th+layer3_th))<(3*a+d) then
   messagebox("The width of the cable tray is too small")
   error()
   quit()
end

if h2<(layer4_th+layer5_th+layer6_th+gap1) then
   messagebox("The height of the U-covering is too small")
   error()
   quit()
end

if (h1-(layer1_th+layer2_th+layer3_th)+gap1)<(d) then
   messagebox("The heighth of the cable tray is too small")
   error()
   quit()
end

if (h1)<(h2-(gap1+layer4_th+layer5_th+layer6_th)) then
   messagebox("The heighth of the cable tray is too small")
   error()
   quit()
end

if a<d then
   messagebox("The cable-to-cable distance is too small")
   error()
   quit()
end

if gap1==0 then
   messagebox("Air gap value must be higher than zero")
   error()
   quit()
end

if gap2==0 then
   messagebox("Air gap value must be higher than zero")
   error()
   quit()
end


-- MATERIALS DEFINITION

mi_getmaterial("Air") -- properties of "Air" are defined in the library

cablematerial_mu = 1 -- material of the cables
cablematerial_sig = 55
mi_addmaterial("cablematerial", cablematerial_mu, cablematerial_mu, foo, foo, cablematerial_sig)


-- CIRCUITS DEFINITION

Ipeak1 = Irms1*sqrt(2)
Ipeak2 = Irms2*sqrt(2)
Ipeak3 = Irms3*sqrt(2)

I1 = Ipeak1 * (cos(angle1) + I*sin(angle1))
I2 = Ipeak2 * (cos(angle2) + I*sin(angle2))
I3 = Ipeak3 * (cos(angle3) + I*sin(angle3))
In = -(I1 + I2 + I3)

mi_addcircprop("I1", I1, 0)
mi_addcircprop("I2", I2, 0)
mi_addcircprop("I3", I3, 0)
mi_addcircprop("In", In, 0)


-- DOMAIN (BOUNDARY CONDITIONS)

bb1 = 16*w1 -- diameter of the first circle (~3 m)
bb2 = w1 -- diameter of the second circle
delta = bb1 + bb2

mi_addboundprop("PB1", foo, foo, foo, foo, foo, foo, foo, foo, 4) -- 4 = "periodic"
mi_addboundprop("PB2", foo, foo, foo, foo, foo, foo, foo, foo, 4)
mi_addpointprop("Azero",0,0)

mi_addnode(-bb1/2,0)
mi_addnode( bb1/2,0)
   mi_addarc(-bb1/2,0,bb1/2,0,180,1)
   mi_addarc(bb1/2,0,-bb1/2,0,180,1)

mi_addnode(-bb2/2+delta,0)
mi_addnode( bb2/2+delta,0)
   mi_addarc(-bb2/2+delta,0,bb2/2+delta,0,180,1)
   mi_addarc( bb2/2+delta,0,-bb2/2+delta,0,180,1)

mi_selectarcsegment(0,bb1/2)
mi_selectarcsegment(delta,bb2/2)
mi_setarcsegmentprop(1,"PB1")
mi_clearselected()

mi_selectarcsegment(0,-bb1/2)
mi_selectarcsegment(delta,-bb2/2)
mi_setarcsegmentprop(1,"PB2")
mi_clearselected()

mi_addnode(delta,0)
mi_selectnode(delta,0)
mi_setnodeprop("Azero")
mi_clearselected()

mi_addblocklabel(delta,bb2/4)
mi_selectlabel(delta,bb2/4)
mi_setblockprop("Air", 0,d)
mi_clearselected()

mi_zoomnatural() -- zoom the dimension of the magnetic circuit in order to fit the window


-- FIRST STAGE: NO CABLE TRAY

-- geometry: power cables & materials

mi_addnode(-d/2-3/2*a,0)
mi_addnode(d/2-3/2*a,0)
mi_addarc(-d/2-3/2*a,0,d/2-3/2*a,0,180,1)
mi_addarc(d/2-3/2*a,0,-d/2-3/2*a,0,180,1)
mi_selectnode(-d/2-3/2*a,0)
mi_selectnode(d/2-3/2*a,0)
mi_selectarcsegment(-3/2*a,d/2)
mi_selectarcsegment(-3/2*a,-d/2)
mi_setarcsegmentprop(5, foo, 0, 1) -- boundary property "propname" = foo
mi_copytranslate(a, 0, 3, 4) -- copy the first cable and paste three copies 

mi_addblocklabel(-3/2*a,0)
mi_selectlabel(-3/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "I1")
mi_clearselected()

mi_addblocklabel(-1/2*a,0)
mi_selectlabel(-1/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "I2")
mi_clearselected()

mi_addblocklabel(1/2*a,0)
mi_selectlabel(1/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "I3")
mi_clearselected()

mi_addblocklabel(3/2*a,0)
mi_selectlabel(3/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "In")
mi_clearselected()

mi_addblocklabel(0, gap1+squareside) --Air Ext.
mi_selectlabel(0, gap1+squareside)
mi_setblockprop("Air", 0, 0.02)
mi_clearselected()

-- ext. square for better mesh size

mi_addnode(-squareside/2,squareside/2) --1SQ
mi_addnode(squareside/2, squareside/2) --2SQ
mi_addnode(squareside/2,-squareside/2) --3SQ
mi_addnode(-squareside/2,-squareside/2) --4SQ
  mi_addsegment(-squareside/2,squareside/2, squareside/2, squareside/2) --1SQ-S2Q
  mi_addsegment(squareside/2, squareside/2, squareside/2,-squareside/2) --2SQ-3SQ
  mi_addsegment(squareside/2,-squareside/2, -squareside/2,-squareside/2) --3SQ-4SQ
  mi_addsegment(-squareside/2,-squareside/2, -squareside/2,squareside/2) --4SQ-1SQ

mi_addblocklabel(0, -2*gap1+squareside/2) --Air SQ.
mi_selectlabel(0, -2*gap1+squareside/2)
mi_setblockprop("Air", 0, 0.005)
mi_clearselected()

-- 1st simulation

mi_analyze()
mi_close()

open("Design_NO-CableTray.ans")
mo_addcontour(w1/2, 0) -- add a point to define a line
mo_addcontour(w1/2+bplotlength, 0)
mo_makeplot(1,501, "RESULTS/NO-CableTray_BPlotDX.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()

open("Design_NO-CableTray.ans")
mo_addcontour(0, h1/2+gap1+layer4_th+layer5_th+layer6_th) 
mo_addcontour(0, h1/2+gap1+layer4_th+layer5_th+layer6_th+bplotlength)
mo_makeplot(1,501, "RESULTS/NO-CableTray_BPlotTOP.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()

open("Design_NO-CableTray.ans")
mo_addcontour(-w1/2, 0)
mo_addcontour(-w1/2-bplotlength, 0)
mo_makeplot(1,501, "RESULTS/NO-CableTray_BPlotSX.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()

open("Design_NO-CableTray.ans")
mo_addcontour(0, -h1/2)
mo_addcontour(0, -h1/2-bplotlength)
mo_makeplot(1,501, "RESULTS/NO-CableTray_BPlotBT.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()


-- SECOND STAGE

newdocument(0)
freq = 50
units = "meters"
type = "planar" -- definition of the problem: "planar" or "axis"
mi_probdef(freq, units, type, 1e-9)
mi_saveas("Design_CableTray.fem")

-- MATERIALS DEFINITION

mi_getmaterial("Air") -- properties of "Air" are defined in the library

cablematerial_mu = 1 -- material of the cables
cablematerial_sig = 55
mi_addmaterial("cablematerial", cablematerial_mu, cablematerial_mu, foo, foo, cablematerial_sig)


-- CIRCUITS DEFINITION

Ipeak1 = Irms1*sqrt(2)
Ipeak2 = Irms2*sqrt(2)
Ipeak3 = Irms3*sqrt(2)

I1 = Ipeak1 * (cos(angle1) + I*sin(angle1))
I2 = Ipeak2 * (cos(angle2) + I*sin(angle2))
I3 = Ipeak3 * (cos(angle3) + I*sin(angle3))
In = -(I1 + I2 + I3)

mi_addcircprop("I1", I1, 0)
mi_addcircprop("I2", I2, 0)
mi_addcircprop("I3", I3, 0)
mi_addcircprop("In", In, 0)


-- DOMAIN (BOUNDARY CONDITIONS)

bb1 = 16*w1 -- diameter of the first circle (~3 m)
bb2 = w1 -- diameter of the second circle
delta = bb1 + bb2

mi_addboundprop("PB1", foo, foo, foo, foo, foo, foo, foo, foo, 4) -- 4 = "periodic"
mi_addboundprop("PB2", foo, foo, foo, foo, foo, foo, foo, foo, 4)
mi_addpointprop("Azero",0,0)

mi_addnode(-bb1/2,0)
mi_addnode( bb1/2,0)
   mi_addarc(-bb1/2,0,bb1/2,0,180,1)
   mi_addarc(bb1/2,0,-bb1/2,0,180,1)

mi_addnode(-bb2/2+delta,0)
mi_addnode( bb2/2+delta,0)
   mi_addarc(-bb2/2+delta,0,bb2/2+delta,0,180,1)
   mi_addarc( bb2/2+delta,0,-bb2/2+delta,0,180,1)

mi_selectarcsegment(0,bb1/2)
mi_selectarcsegment(delta,bb2/2)
mi_setarcsegmentprop(1,"PB1")
mi_clearselected()

mi_selectarcsegment(0,-bb1/2)
mi_selectarcsegment(delta,-bb2/2)
mi_setarcsegmentprop(1,"PB2")
mi_clearselected()

mi_addnode(delta,0)
mi_selectnode(delta,0)
mi_setnodeprop("Azero")
mi_clearselected()

mi_addblocklabel(delta,bb2/4)
mi_selectlabel(delta,bb2/4)
mi_setblockprop("Air", 0,d)
mi_clearselected()

mi_zoomnatural() -- zoom the dimension of the magnetic circuit in order to fit the window

-- geometry: power cables & materials

mi_addnode(-d/2-3/2*a,0)
mi_addnode(d/2-3/2*a,0)
mi_addarc(-d/2-3/2*a,0,d/2-3/2*a,0,180,1)
mi_addarc(d/2-3/2*a,0,-d/2-3/2*a,0,180,1)
mi_selectnode(-d/2-3/2*a,0)
mi_selectnode(d/2-3/2*a,0)
mi_selectarcsegment(-3/2*a,d/2)
mi_selectarcsegment(-3/2*a,-d/2)
mi_setarcsegmentprop(5, foo, 0, 1) -- boundary property "propname" = foo
mi_copytranslate(a, 0, 3, 4) -- copy the first cable and paste three copies 

mi_addblocklabel(-3/2*a,0)
mi_selectlabel(-3/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "I1")
mi_clearselected()

mi_addblocklabel(-1/2*a,0)
mi_selectlabel(-1/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "I2")
mi_clearselected()

mi_addblocklabel(1/2*a,0)
mi_selectlabel(1/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "I3")
mi_clearselected()

mi_addblocklabel(3/2*a,0)
mi_selectlabel(3/2*a,0)
mi_setblockprop("cablematerial", 0, d/6, "In")
mi_clearselected()

mi_addblocklabel(0, gap1+squareside) --Air Ext.
mi_selectlabel(0, gap1+squareside)
mi_setblockprop("Air", 0, 0.02)
mi_clearselected()

-- ext. square for better mesh size

mi_addnode(-squareside/2,squareside/2) --1SQ
mi_addnode(squareside/2, squareside/2) --2SQ
mi_addnode(squareside/2,-squareside/2) --3SQ
mi_addnode(-squareside/2,-squareside/2) --4SQ
  mi_addsegment(-squareside/2,squareside/2, squareside/2, squareside/2) --1SQ-S2Q
  mi_addsegment(squareside/2, squareside/2, squareside/2,-squareside/2) --2SQ-3SQ
  mi_addsegment(squareside/2,-squareside/2, -squareside/2,-squareside/2) --3SQ-4SQ
  mi_addsegment(-squareside/2,-squareside/2, -squareside/2,squareside/2) --4SQ-1SQ

mi_addblocklabel(0, -2*gap1+squareside/2) --Air SQ.
mi_selectlabel(0, -2*gap1+squareside/2)
mi_setblockprop("Air", 0, 0.005)
mi_clearselected()


-- materials definition

mi_addmaterial("Material 1", layer1_mu, layer1_mu, foo, foo, layer1_sig) -- foo, non-defined variable
mi_addmaterial("Material 2", layer2_mu, layer2_mu, foo, foo, layer2_sig) 
mi_addmaterial("Material 3", layer3_mu, layer3_mu, foo, foo, layer3_sig) 
mi_addmaterial("Material 4", layer4_mu, layer4_mu, foo, foo, layer4_sig) 
mi_addmaterial("Material 5", layer5_mu, layer5_mu, foo, foo, layer5_sig) 
mi_addmaterial("Material 6", layer6_mu, layer6_mu, foo, foo, layer6_sig) 

--  zero current circuits
mi_addcircprop("Izero1", 0, 0) 
mi_addcircprop("Izero2", 0, 0) 
mi_addcircprop("Izero3", 0, 0) 
mi_addcircprop("Izero4", 0, 0)
mi_addcircprop("Izero5", 0, 0) 
mi_addcircprop("Izero6", 0, 0)

-- geometry

-- Layer 1
mi_addnode(w1/2-layer3_th-layer2_th-layer1_th, h1/2) -- node 1
mi_addnode(w1/2-layer3_th-layer2_th-layer1_th, -h1/2+layer3_th+layer2_th+layer1_th) -- node 2
mi_addnode(-w1/2+layer3_th+layer2_th+layer1_th, -h1/2+layer3_th+layer2_th+layer1_th) --node 3
mi_addnode(-w1/2+layer3_th+layer2_th+layer1_th, h1/2) -- node 4
mi_addnode(w1/2-layer3_th-layer2_th, h1/2) -- node 5
mi_addnode(w1/2-layer3_th-layer2_th, -h1/2+layer3_th+layer2_th) -- node 6
mi_addnode(-w1/2+layer3_th+layer2_th, -h1/2+layer3_th+layer2_th) -- node 7
mi_addnode(-w1/2+layer3_th+layer2_th, h1/2) -- node 8
   mi_addsegment(w1/2-layer3_th-layer2_th-layer1_th, h1/2, w1/2-layer3_th-layer2_th-layer1_th, -h1/2+layer3_th+layer2_th+layer1_th) -- 1-2
   mi_addsegment(w1/2-layer3_th-layer2_th-layer1_th, -h1/2+layer3_th+layer2_th+layer1_th, -w1/2+layer3_th+layer2_th+layer1_th, -h1/2+layer3_th+layer2_th+layer1_th) -- 2-3
   mi_addsegment(-w1/2+layer3_th+layer2_th+layer1_th, -h1/2+layer3_th+layer2_th+layer1_th, -w1/2+layer3_th+layer2_th+layer1_th, h1/2) -- 3-4
   mi_addsegment(w1/2-layer3_th-layer2_th-layer1_th, h1/2, w1/2-layer3_th-layer2_th, h1/2) -- 1-5
   mi_addsegment(w1/2-layer3_th-layer2_th, h1/2, w1/2-layer3_th-layer2_th, -h1/2+layer3_th+layer2_th) -- 5-6
   mi_addsegment(w1/2-layer3_th-layer2_th, -h1/2+layer3_th+layer2_th, -w1/2+layer3_th+layer2_th, -h1/2+layer3_th+layer2_th) -- 6-7
   mi_addsegment(-w1/2+layer3_th+layer2_th, -h1/2+layer3_th+layer2_th, -w1/2+layer3_th+layer2_th, h1/2) -- 7-8
   mi_addsegment(-w1/2+layer3_th+layer2_th, h1/2, -w1/2+layer3_th+layer2_th+layer1_th, h1/2) -- 8-4

-- Layer 2
mi_addnode(w1/2-layer3_th, h1/2) -- node 9
mi_addnode(w1/2-layer3_th, -h1/2+layer3_th) -- node 10 
mi_addnode(-w1/2+layer3_th, -h1/2+layer3_th) -- node 11
mi_addnode(-w1/2+layer3_th, h1/2) -- node 12
   mi_addsegment(w1/2-layer3_th-layer2_th, h1/2, w1/2-layer3_th, h1/2) -- 5-9
   mi_addsegment(w1/2-layer3_th, h1/2, w1/2-layer3_th, -h1/2+layer3_th) -- 9-10
   mi_addsegment(w1/2-layer3_th, -h1/2+layer3_th, -w1/2+layer3_th, -h1/2+layer3_th) -- 10-11
   mi_addsegment(-w1/2+layer3_th, -h1/2+layer3_th, -w1/2+layer3_th, h1/2) -- 11-12
   mi_addsegment(-w1/2+layer3_th, h1/2, -w1/2+layer3_th+layer2_th, h1/2) -- 12-8

-- Layer 3
mi_addnode(w1/2, h1/2) -- node 13
mi_addnode(w1/2, -h1/2) -- node 14
mi_addnode(-w1/2, -h1/2) -- node 15
mi_addnode(-w1/2, h1/2) --node 16
    mi_addsegment(w1/2-layer3_th, h1/2, w1/2, h1/2) -- 9-13
    mi_addsegment(w1/2, h1/2, w1/2, -h1/2) -- 13-14
    mi_addsegment(w1/2, -h1/2, -w1/2, -h1/2) -- 14-15
    mi_addsegment(-w1/2, -h1/2, -w1/2, h1/2) -- 15-16
    mi_addsegment(-w1/2, h1/2, -w1/2+layer3_th, h1/2) -- 16-12

-- Layer 4
mi_addnode(w1/2+gap2, h1/2+gap1) -- node 19
mi_addnode(w1/2+gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 20
mi_addnode(-w1/2-gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 21
mi_addnode(-w1/2-gap2, h1/2+gap1) -- node 22
mi_addnode(w1/2+gap2+layer4_th, h1/2+gap1+layer4_th) -- node 23
mi_addnode(w1/2+gap2+layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 24
mi_addnode(-w1/2-gap2-layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 25
mi_addnode(-w1/2-gap2-layer4_th, h1/2+gap1+layer4_th) -- node 26
    mi_addsegment(w1/2+gap2, h1/2+gap1, w1/2+gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 19-20 
    mi_addsegment(w1/2+gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, w1/2+gap2+layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 20-24
    mi_addsegment(w1/2+gap2+layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, w1/2+gap2+layer4_th, h1/2+gap1+layer4_th) -- 24-23
    mi_addsegment(w1/2+gap2+layer4_th, h1/2+gap1+layer4_th, -w1/2-gap2-layer4_th, h1/2+gap1+layer4_th) -- 23-26
    mi_addsegment(-w1/2-gap2-layer4_th, h1/2+gap1+layer4_th, -w1/2-gap2-layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 26-25
    mi_addsegment(-w1/2-gap2-layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, -w1/2-gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 25-21
    mi_addsegment(-w1/2-gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, -w1/2-gap2, h1/2+gap1) -- 21-22
    mi_addsegment(-w1/2-gap2, h1/2+gap1, w1/2+gap2, h1/2+gap1) -- 22-19

-- Layer 5
mi_addnode(w1/2+gap2+layer4_th+layer5_th, h1/2+gap1+layer4_th+layer5_th) -- node 27
mi_addnode(w1/2+gap2+layer4_th+layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 28
mi_addnode(-w1/2-gap2-layer4_th-layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 29
mi_addnode(-w1/2-gap2-layer4_th-layer5_th, h1/2+gap1+layer4_th+layer5_th) -- node 30
    mi_addsegment(w1/2+gap2+layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, w1/2+gap2+layer4_th+layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 24-28
    mi_addsegment(w1/2+gap2+layer4_th+layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, w1/2+gap2+layer4_th+layer5_th, h1/2+gap1+layer4_th+layer5_th) -- 28-27
    mi_addsegment(w1/2+gap2+layer4_th+layer5_th, h1/2+gap1+layer4_th+layer5_th, -w1/2-gap2-layer4_th-layer5_th, h1/2+gap1+layer4_th+layer5_th) -- 27-30
    mi_addsegment(-w1/2-gap2-layer4_th-layer5_th, h1/2+gap1+layer4_th+layer5_th, -w1/2-gap2-layer4_th-layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 30-29
    mi_addsegment(-w1/2-gap2-layer4_th-layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, -w1/2-gap2-layer4_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 29-25

-- Layer 6
mi_addnode(w1/2+gap2+layer4_th+layer5_th+layer6_th, h1/2+gap1+layer4_th+layer5_th+layer6_th) -- node 31
mi_addnode(w1/2+gap2+layer4_th+layer5_th+layer6_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 32
mi_addnode(-w1/2-gap2-layer4_th-layer5_th-layer6_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 33
mi_addnode(-w1/2-gap2-layer4_th-layer5_th-layer6_th, h1/2+gap1+layer4_th+layer5_th+layer6_th) -- node 34
    mi_addsegment(w1/2+gap2+layer4_th+layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, w1/2+gap2+layer4_th+layer5_th+layer6_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 28-32
    mi_addsegment(w1/2+gap2+layer4_th+layer5_th+layer6_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, w1/2+gap2+layer4_th+layer5_th+layer6_th, h1/2+gap1+layer4_th+layer5_th+layer6_th) -- 32-31
    mi_addsegment(w1/2+gap2+layer4_th+layer5_th+layer6_th, h1/2+gap1+layer4_th+layer5_th+layer6_th, -w1/2-gap2-layer4_th-layer5_th-layer6_th, h1/2+gap1+layer4_th+layer5_th+layer6_th) -- 31-34
    mi_addsegment(-w1/2-gap2-layer4_th-layer5_th-layer6_th, h1/2+gap1+layer4_th+layer5_th+layer6_th, -w1/2-gap2-layer4_th-layer5_th-layer6_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 34-33
    mi_addsegment(-w1/2-gap2-layer4_th-layer5_th-layer6_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, -w1/2-gap2-layer4_th-layer5_th, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 33-29

-- air gap
mi_addnode(-w1/2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 17
mi_addnode(w1/2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- node 18
mi_addnode(-w1/2+layer3_th+layer2_th+layer1_th, h1/2+gap1) -- node 35
mi_addnode(w1/2-layer3_th-layer2_th-layer1_th, h1/2+gap1) -- node 36
   mi_addsegment(w1/2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, w1/2+gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) -- 18-20
   mi_addsegment(-w1/2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th, -w1/2-gap2, h1/2-h2+gap1+layer4_th+layer5_th+layer6_th) --17-21
   mi_addsegment(-w1/2+layer3_th+layer2_th+layer1_th, h1/2, -w1/2+layer3_th+layer2_th+layer1_th, h1/2+gap1) --4-35
   mi_addsegment(w1/2-layer3_th-layer2_th-layer1_th, h1/2, w1/2-layer3_th-layer2_th-layer1_th, h1/2+gap1) --1-36


-- assignment of the materials

mi_addblocklabel(0, -h1/2+layer3_th+layer2_th+layer1_th/2)
mi_selectlabel(0, -h1/2+layer3_th+layer2_th+layer1_th/2)
mi_setblockprop("Material 1", 0,layer1_th/3,"Izero1")
mi_clearselected()

mi_addblocklabel(0, -h1/2+layer3_th+layer2_th/2)
mi_selectlabel(0, -h1/2+layer3_th+layer2_th/2)
mi_setblockprop("Material 2", 0,layer2_th/3,"Izero2")
mi_clearselected()

mi_addblocklabel(0, -h1/2+layer3_th/2)
mi_selectlabel(0,  -h1/2+layer3_th/2)
mi_setblockprop("Material 3", 0,layer3_th/3,"Izero3")
mi_clearselected()

mi_addblocklabel(0, h1/2+gap1+layer4_th/2)
mi_selectlabel(0,  h1/2+gap1+layer4_th/2)
mi_setblockprop("Material 4", 0,layer4_th/3,"Izero4")
mi_clearselected()

mi_addblocklabel(0, h1/2+gap1+layer4_th+layer5_th/2)
mi_selectlabel(0,  h1/2+gap1+layer4_th+layer5_th/2)
mi_setblockprop("Material 5", 0,layer5_th/2,"Izero5")
mi_clearselected()

mi_addblocklabel(0, h1/2+gap1+layer4_th+layer5_th+layer6_th/2)
mi_selectlabel(0,  h1/2+gap1+layer4_th+layer5_th+layer6_th/2)
mi_setblockprop("Material 6", 0,layer6_th/3,"Izero6")
mi_clearselected()

mi_addblocklabel(0, h1/2+gap1/2) --Air Int.
mi_selectlabel(0, h1/2+gap1/2)
mi_setblockprop("Air", 0, d/6)
mi_clearselected()

mi_addblocklabel(w1/2-layer3_th, h1/2+gap1/2) --Air Int. DX
mi_selectlabel(w1/2-layer3_th, h1/2+gap1/2)
mi_setblockprop("Air", 0, d/6)
mi_clearselected()

mi_addblocklabel(-w1/2+layer3_th, h1/2+gap1/2) --Air Int. SX
mi_selectlabel(-w1/2+layer3_th, h1/2+gap1/2)
mi_setblockprop("Air", 0, d/6)
mi_clearselected()


-- 2nd simulation

mi_analyze()
mi_close()

open("Design_CableTray.ans")
mo_addcontour(w1/2, 0) -- add a point to define a line
mo_addcontour(w1/2+bplotlength, 0)
mo_makeplot(1,501, "RESULTS/CableTray_BPlotDX.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()

open("Design_CableTray.ans")
mo_addcontour(0, h1/2+gap1+layer4_th+layer5_th+layer6_th) 
mo_addcontour(0, h1/2+gap1+layer4_th+layer5_th+layer6_th+bplotlength)
mo_makeplot(1,501, "RESULTS/CableTray_BPlotTOP.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()

open("Design_CableTray.ans")
mo_addcontour(-w1/2, 0)
mo_addcontour(-w1/2-bplotlength, 0)
mo_makeplot(1,501, "RESULTS/CableTray_BPlotSX.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()

open("Design_CableTray.ans")
mo_addcontour(0, -h1/2)
mo_addcontour(0, -h1/2-bplotlength)
mo_makeplot(1,501, "RESULTS/CableTray_BPlotBT.txt", 0)
mo_makeplot(1, 501)

mo_clearcontour()
